@@ -13,9 +13,9 @@
 #include "publishdialog.h"
 #include "utils_p.h"
 
-#include <agentinstance.h>
-#include <agentmanager.h>
-#include <contactsearchjob.h>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentManager>
+#include <Akonadi/ContactSearchJob>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/FreeBusy>
@@ -29,7 +29,7 @@
 #include <KLocalizedString>
 #include <QUrl>
 
-#include <KJobWidgets/KJobWidgets>
+#include <KJobWidgets>
 #include <QDir>
 #include <QFile>
 #include <QRegularExpression>
@@ -56,9 +56,9 @@ QUrl replaceVariablesUrl(const QUrl &url, const QString &email)
     }
 
     QString saveStr = url.path();
-    saveStr.replace(QRegularExpression(QStringLiteral("%email%"), QRegularExpression::CaseInsensitiveOption), email);
-    saveStr.replace(QRegularExpression(QStringLiteral("%name%"), QRegularExpression::CaseInsensitiveOption), emailName);
-    saveStr.replace(QRegularExpression(QStringLiteral("%server%"), QRegularExpression::CaseInsensitiveOption), emailHost);
+    saveStr.replace(QStringLiteral("%email%"), email, Qt::CaseInsensitive);
+    saveStr.replace(QStringLiteral("%name%"), emailName, Qt::CaseInsensitive);
+    saveStr.replace(QStringLiteral("%server%"), emailHost, Qt::CaseInsensitive);
 
     QUrl retUrl(url);
     retUrl.setPath(saveStr);
@@ -132,8 +132,7 @@ FreeBusyManagerPrivate::FreeBusyProviderRequest::FreeBusyProviderRequest(const Q
 /// FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue
 
 FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue()
-    : mHandlersCount(0)
-    , mResultingFreeBusy(nullptr)
+    : mResultingFreeBusy(nullptr)
 {
     // Set the start of the period to today 00:00:00
     mStartTime = QDateTime(QDate::currentDate(), QTime());
@@ -142,8 +141,7 @@ FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequest
 }
 
 FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue(const QDateTime &start, const QDateTime &end)
-    : mHandlersCount(0)
-    , mResultingFreeBusy(nullptr)
+    : mResultingFreeBusy(nullptr)
 {
     mStartTime = start;
     mEndTime = end;
@@ -155,9 +153,6 @@ FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequest
 FreeBusyManagerPrivate::FreeBusyManagerPrivate(FreeBusyManager *q)
     : QObject()
     , q_ptr(q)
-    , mTimerID(0)
-    , mUploadingFreeBusy(false)
-    , mBrokenUrl(false)
     , mParentWidgetForRetrieval(nullptr)
 {
     connect(this, &FreeBusyManagerPrivate::freeBusyUrlRetrieved, this, &FreeBusyManagerPrivate::finishProcessRetrieveQueue);
@@ -170,7 +165,7 @@ QString FreeBusyManagerPrivate::freeBusyDir() const
 
 void FreeBusyManagerPrivate::checkFreeBusyUrl()
 {
-    QUrl targetURL(CalendarSettings::self()->freeBusyPublishUrl());
+    const QUrl targetURL(CalendarSettings::self()->freeBusyPublishUrl());
     mBrokenUrl = targetURL.isEmpty() || !targetURL.isValid();
 }
 
@@ -321,12 +316,14 @@ void FreeBusyManagerPrivate::fbCheckerJobFinished(KJob *job)
     const QString email = job->property("email").toString();
     if (!job->error()) {
         auto checkerJob = static_cast<FbCheckerJob *>(job);
-        QUrl dirURL = checkerJob->validUrl();
-        // write the URL to the cache
-        KConfig cfg(configFile());
-        KConfigGroup group = cfg.group(email);
-        group.writeEntry("url", dirURL.toDisplayString()); // prettyURL() does not write user nor password
-        qCDebug(AKONADICALENDAR_LOG) << "Found url email=" << email << "; url=" << dirURL;
+        const QUrl dirURL = checkerJob->validUrl();
+        if (dirURL.isValid()) {
+            // write the URL to the cache
+            KConfig cfg(configFile());
+            KConfigGroup group = cfg.group(email);
+            group.writeEntry("url", dirURL.toDisplayString()); // prettyURL() does not write user nor password
+            qCDebug(AKONADICALENDAR_LOG) << "Found url email=" << email << "; url=" << dirURL;
+        }
         Q_EMIT freeBusyUrlRetrieved(email, dirURL);
     } else {
         qCDebug(AKONADICALENDAR_LOG) << "Returning invalid url";
@@ -354,8 +351,8 @@ KCalendarCore::FreeBusy::Ptr FreeBusyManagerPrivate::iCalToFreeBusy(const QByteA
 
 KCalendarCore::FreeBusy::Ptr FreeBusyManagerPrivate::ownerFreeBusy()
 {
-    QDateTime start = QDateTime::currentDateTimeUtc();
-    QDateTime end = start.addDays(CalendarSettings::self()->freeBusyPublishDays());
+    const QDateTime start = QDateTime::currentDateTimeUtc();
+    const QDateTime end = start.addDays(CalendarSettings::self()->freeBusyPublishDays());
 
     KCalendarCore::Event::List events = mCalendar ? mCalendar->rawEvents(start.date(), end.date()) : KCalendarCore::Event::List();
     KCalendarCore::FreeBusy::Ptr freebusy(new KCalendarCore::FreeBusy(events, start, end));
@@ -439,10 +436,10 @@ void FreeBusyManagerPrivate::processRetrieveQueue()
         return;
     }
 
-    QString email = mRetrieveQueue.takeFirst();
+    const QString email = mRetrieveQueue.takeFirst();
 
     // First, try to find all agents that are free-busy providers
-    QStringList providers = getFreeBusyProviders();
+    const QStringList providers = getFreeBusyProviders();
     qCDebug(AKONADICALENDAR_LOG) << "Got the following FreeBusy providers: " << providers;
 
     // If some free-busy providers were found let's query them first and ask them
@@ -547,8 +544,9 @@ void FreeBusyManagerPrivate::queryFreeBusyProviders(const QStringList &providers
     for (const QString &provider : providers) {
         FreeBusyProviderRequest request(provider);
 
-        connect(request.mInterface.data(), SIGNAL(handlesFreeBusy(QString, bool)), this, SLOT(onHandlesFreeBusy(QString, bool)));
-
+        // clang-format off
+        connect(request.mInterface.data(), SIGNAL(handlesFreeBusy(QString,bool)), this, SLOT(onHandlesFreeBusy(QString,bool)));
+        // clang-format on
         request.mInterface->call(QStringLiteral("canHandleFreeBusy"), email);
         request.mRequestStatus = FreeBusyProviderRequest::HandlingRequested;
         mProvidersRequestsByEmail[email].mRequests << request;
@@ -570,7 +568,7 @@ void FreeBusyManagerPrivate::onHandlesFreeBusy(const QString &email, bool handle
         return;
     }
 
-    auto iface = dynamic_cast<QDBusInterface *>(sender());
+    auto iface = qobject_cast<QDBusInterface *>(sender());
     if (!iface) {
         return;
     }
@@ -590,9 +588,9 @@ void FreeBusyManagerPrivate::onHandlesFreeBusy(const QString &email, bool handle
     if (requestIndex == -1) {
         return;
     }
-
-    disconnect(iface, SIGNAL(handlesFreeBusy(QString, bool)), this, SLOT(onHandlesFreeBusy(QString, bool)));
-
+    // clang-format off
+    disconnect(iface, SIGNAL(handlesFreeBusy(QString,bool)), this, SLOT(onHandlesFreeBusy(QString,bool)));
+    // clang-format on
     if (!handles) {
         queue->mRequests.removeAt(requestIndex);
         // If no more requests are left and no handler responded
@@ -603,7 +601,9 @@ void FreeBusyManagerPrivate::onHandlesFreeBusy(const QString &email, bool handle
         }
     } else {
         ++queue->mHandlersCount;
-        connect(iface, SIGNAL(freeBusyRetrieved(QString, QString, bool, QString)), this, SLOT(onFreeBusyRetrieved(QString, QString, bool, QString)));
+        // clang-format off
+        connect(iface, SIGNAL(freeBusyRetrieved(QString,QString,bool,QString)), this, SLOT(onFreeBusyRetrieved(QString,QString,bool,QString)));
+        // clang-format on
         iface->call(QStringLiteral("retrieveFreeBusy"), email, queue->mStartTime, queue->mEndTime);
         queue->mRequests[requestIndex].mRequestStatus = FreeBusyProviderRequest::FreeBusyRequested;
     }
@@ -651,9 +651,9 @@ void FreeBusyManagerPrivate::onFreeBusyRetrieved(const QString &email, const QSt
     if (requestIndex == -1) {
         return;
     }
-
-    disconnect(iface, SIGNAL(freeBusyRetrieved(QString, QString, bool, QString)), this, SLOT(onFreeBusyRetrieved(QString, QString, bool, QString)));
-
+    // clang-format off
+    disconnect(iface, SIGNAL(freeBusyRetrieved(QString,QString,bool,QString)), this, SLOT(onFreeBusyRetrieved(QString,QString,bool,QString)));
+    // clang-format on
     queue->mRequests.removeAt(requestIndex);
 
     if (success) {
@@ -695,10 +695,7 @@ FreeBusyManager::FreeBusyManager()
     connect(CalendarSettings::self(), SIGNAL(configChanged()), SLOT(checkFreeBusyUrl()));
 }
 
-FreeBusyManager::~FreeBusyManager()
-{
-    delete d_ptr;
-}
+FreeBusyManager::~FreeBusyManager() = default;
 
 FreeBusyManager *FreeBusyManager::self()
 {
@@ -937,12 +934,12 @@ KCalendarCore::FreeBusy::Ptr FreeBusyManager::loadFreeBusy(const QString &email)
     QFile f(fbd + QLatin1Char('/') + email + QStringLiteral(".ifb"));
     if (!f.exists()) {
         qCDebug(AKONADICALENDAR_LOG) << f.fileName() << "doesn't exist.";
-        return KCalendarCore::FreeBusy::Ptr();
+        return {};
     }
 
     if (!f.open(QIODevice::ReadOnly)) {
         qCDebug(AKONADICALENDAR_LOG) << "Unable to open file" << f.fileName();
-        return KCalendarCore::FreeBusy::Ptr();
+        return {};
     }
 
     QTextStream ts(&f);
